PALM-meteo: palmmeteo.library.QuantityCalculator Class Reference

PALM-meteo

Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
palmmeteo.library.QuantityCalculator Class Reference

## Public Member Functions
def | __init__ (self, quantities, var_defs, preprocessors, regridder)
def | load_timestep_vars (self, f, tindex, tsdata)
def | validate_timestep (self, tsdata)
def | calc_timestep_species (self, tsdata)

## Static Public Member Functions
def | new_timestep ()

## Public Attributes
| regridder
| loaded_vars
| preprocessors
| validations
| quantities

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.library.QuantityCalculator.__init__ | ( |  | self,
|  |  | quantities,
|  |  | var_defs,
|  |  | preprocessors,
|  |  | regridder
| ) |  |

## Member Function Documentation

## ◆ calc_timestep_species()

def palmmeteo.library.QuantityCalculator.calc_timestep_species | ( |  | self,
|  |  | tsdata
| ) |  |

## ◆ load_timestep_vars()

def palmmeteo.library.QuantityCalculator.load_timestep_vars | ( |  | self,
|  |  | f,
|  |  | tindex,
|  |  | tsdata
| ) |  |

## ◆ new_timestep()

def palmmeteo.library.QuantityCalculator.new_timestep | ( |  | ) |
| static

## ◆ validate_timestep()

def palmmeteo.library.QuantityCalculator.validate_timestep | ( |  | self,
|  |  | tsdata
| ) |  |

## Member Data Documentation

## ◆ loaded_vars

palmmeteo.library.QuantityCalculator.loaded_vars

## ◆ preprocessors

palmmeteo.library.QuantityCalculator.preprocessors

## ◆ quantities

palmmeteo.library.QuantityCalculator.quantities

## ◆ regridder

palmmeteo.library.QuantityCalculator.regridder

## ◆ validations

palmmeteo.library.QuantityCalculator.validations

The documentation for this class was generated from the following file:

- palmmeteo/library.py